@@ -34,6 +34,11 @@
 
 #include <libbonoboui.h>
 
+/* following function is not public, so we define the prototype here ... */
+void	bonobo_dock_item_set_behavior	(BonoboDockItem         *dock_item,
+					 BonoboDockItemBehavior  behavior);
+
+
 #define INT(s)   (strtol ((s), NULL, 0))
 #define BOOL(s)  (g_ascii_tolower (*(s)) == 't' || g_ascii_tolower (*(s)) == 'y' || INT (s))
 #define FLOAT(s) (g_strtod ((s), NULL))
@@ -138,7 +143,7 @@ menushell_build_children (GladeXML *xml, GtkWidget *w,
 #if 0
     GtkAccelGroup *uline = NULL;
     
-    if (strcmp (info->class, "GtkMenuBar") != 0) {
+    if (strcmp (info->classname, "GtkMenuBar") != 0) {
 	uline = gtk_menu_ensure_uline_accel_group (GTK_MENU (w));
 	glade_xml_push_uline_accel (xml, uline);
     }
@@ -194,7 +199,7 @@ menushell_build_children (GladeXML *xml, GtkWidget *w,
 	glade_xml_pop_uline_accel(xml);
 #endif
 #if 0
-    if (strcmp(info->class, "GtkMenuBar") != 0 &&
+    if (strcmp(info->classname, "GtkMenuBar") != 0 &&
 	gnome_preferences_get_menus_have_tearoff()) {
 	GtkWidget *tearoff = gtk_tearoff_menu_item_new();
 	
@@ -221,7 +226,7 @@ gnome_add_dock_item (GladeXML *xml,
 	band = offset = position = 0;
 	placement = BONOBO_DOCK_TOP;
 	behavior  = BONOBO_DOCK_ITEM_BEH_NORMAL;
-	
+
 	for (i = 0; i < childinfo->n_properties; i++) {
 		const char *name  = childinfo->properties[i].name;
 		const char *value = childinfo->properties[i].value;
@@ -246,6 +251,8 @@ gnome_add_dock_item (GladeXML *xml,
 
 	toplevel = gtk_widget_get_ancestor (parent, GNOME_TYPE_APP);
 
+	bonobo_dock_item_set_behavior (BONOBO_DOCK_ITEM (child), behavior);
+
 	if (toplevel != NULL) {
 	    gnome_app_add_dock_item (
 		GNOME_APP (toplevel),
@@ -276,7 +283,7 @@ gnome_dock_build_children (GladeXML *xml, GtkWidget *w, GladeWidgetInfo *info)
 	for (i = 0; i < info->n_children; i++) {
 		childinfo = &info->children[i];
 
-		if (!strcmp (childinfo->child->class, "BonoboDockItem")) {
+		if (!strcmp (childinfo->child->classname, "BonoboDockItem")) {
 			gnome_add_dock_item (xml, w, info, childinfo);
 			continue;
 		}
@@ -472,13 +479,13 @@ druid_page_edge_new (GladeXML *xml, GType widget_type,
 	    title = value;
 	else if (!strcmp (name, "logo_image")) {
 	    if (logo)
-		gdk_pixbuf_unref (logo);
+		g_object_unref (G_OBJECT (logo));
 	    filename = glade_xml_relative_file (xml, value);
 	    logo = gdk_pixbuf_new_from_file (filename, NULL);
 	    g_free (filename);
 	} else if (!strcmp (name, "watermark_image")) {
 	    if (watermark)
-		gdk_pixbuf_unref (watermark);
+		g_object_unref (G_OBJECT (watermark));
 	    filename = glade_xml_relative_file (xml, value);
 	    watermark = gdk_pixbuf_new_from_file (filename, NULL);
 	    g_free (filename);
@@ -493,11 +500,11 @@ druid_page_edge_new (GladeXML *xml, GType widget_type,
     
 
     if (logo)
-	gdk_pixbuf_unref (logo);
+	g_object_unref (G_OBJECT (logo));
     if (watermark)
-	gdk_pixbuf_unref (watermark);
+	g_object_unref (G_OBJECT (watermark));
     if (top_watermark)
-	gdk_pixbuf_unref (top_watermark);
+	g_object_unref (G_OBJECT (top_watermark));
 
     return druid;
 }
@@ -673,6 +680,31 @@ icon_list_set_selection_mode (GladeXML *xml, GtkWidget *w,
 				value));
 }
 
+static void
+entry_set_max_saved (GladeXML *xml, GtkWidget *w,
+		     const char *name, const char *value)
+{
+    gnome_entry_set_max_saved (GNOME_ENTRY (w), INT (value));
+}
+
+static void
+file_entry_set_max_saved (GladeXML *xml, GtkWidget *w,
+			  const char *name, const char *value)
+{
+    entry_set_max_saved (xml, 
+			 gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (w)),
+			 name, value);
+}
+
+static void
+icon_entry_set_max_saved (GladeXML *xml, GtkWidget *w,
+			  const char *name, const char *value)
+{
+    entry_set_max_saved (xml,
+			 gnome_icon_entry_gnome_entry (GNOME_ICON_ENTRY (w)),
+			 name, value);
+}
+
 static void
 icon_list_set_row_spacing (GladeXML *xml, GtkWidget *w,
 			   const char *name, const char *value)
@@ -784,6 +816,9 @@ glade_module_register_widgets (void)
     glade_register_custom_prop (GTK_TYPE_IMAGE_MENU_ITEM, "stock_item", custom_noop);
     glade_register_custom_prop (GTK_TYPE_MENU_ITEM, "stock_item", custom_noop);
     glade_register_custom_prop (GNOME_TYPE_PIXMAP, "filename", pixmap_set_filename);
+    glade_register_custom_prop (GNOME_TYPE_ENTRY, "max_saved", entry_set_max_saved);
+    glade_register_custom_prop (GNOME_TYPE_FILE_ENTRY, "max_saved", file_entry_set_max_saved);
+    glade_register_custom_prop (GNOME_TYPE_ICON_ENTRY, "max_saved", icon_entry_set_max_saved);
 
     glade_register_widget (GNOME_TYPE_ABOUT, NULL, NULL, NULL);
     glade_register_widget (GNOME_TYPE_APP, app_build, app_build_children,
